==> generator-baukasten-4.1.0.tgz: package/generators/app/templates/___src/_craftCMS3/craft-gonzo.php <==
<?php
return [
    "compFolders" => [
        "_atoms",
        "_molecules",
        "_organisms",
        "_embeds",
        "_views"
    ],
    "mqButtons" => [
        "min" => "320px",
        "xs" => "400px",
        "s" => "600px",
        "m" => "800px",
        "l" => "1000px",
        "max" => "1440px",
        "fluid" => "100vw"
    ],
    "compStatus" => [
        0 => ["name" => "wip", "color" => "#FF9800"],
        1 => ["name" => "review", "color" => "#E91E63"],
        2 => ["name" => "done", "color" => "#4CAF50"],
        3 => ["name" => "discarded", "color" => "#F44336"],
    ],
    "pages" => [
        'typography' => [
            'label' => 'Typography',
            'options' => [
                'glyphsLower' => [
                    'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
                    'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
                ],
                'glyphsUpper' => [
                    'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
                    'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
                ],
                'glyphsLigatures' => [
                    'ﬀ', 'ﬁ', 'ﬂ', 'ﬃ', 'ﬄ'
                ],
                'glyphsPunctuation' => [
                    '!', '"', '#', '%', '&', '\'', '(', ')', '*', ',', '.', '/', ':', ';',
                    '?', '@', '[', '\\', ']', '^', '_', '`', '{', '|', '}', '˜', '¡', '¦',
                    '§', '¨', '©', 'ª', '«', '¬', '®', '¯', '²', '³', '´', '¶', '·', '¹',
                    'º', '»', '¿', '‐', '–', '—', '―', '‘', '’', '‚', '“', '”', '„', '•',
                    '™',
                ],
                'glyphsCurrency' => [
                    '$', '¢', '£', '€', '¥', '฿'
                ],
                'headline' => 'The quick brown fox jumps over a Dog. Zwei Boxkämpfer jagen Eva durch Sylt portez ce vieux Whiskey blond.',
                'textSimple' => '
                  <p>
                    Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.
                  </p>',
                'textFull' => '
                  <p>
                    Shooting <del>highlining</del> in front of the <strong>supermoo*n</strong> was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical <mark>landscape photograph</mark>. It started as a simple challenge to myself and I <a href="#">quickly became</a> immersed in the process of figuring out how to shoot it.
                  </p>
                  <ul>
                    <li>Shooting highlining in front of the supermoo</li>
                    <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                    <li>I’ve *chased to date.
                      <ul>
                        <li>Shooting highlining in front of the supermoo</li>
                        <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                        <li>I’ve *chased to date.</li>
                      </ul>
                    </li>
                  </ul>
                  <p>
                    <em>Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.</em>
                  </p>
                  <p>
                    <strong>Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.</strong>
                  </p>
                  <ol>
                    <li>Shooting highlining in front of the supermoo</li>
                    <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                    <li>I’ve *chased to date.
                      <ol>
                        <li>Shooting highlining in front of the supermoo</li>
                        <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                        <li>I’ve *chased to date.</li>
                      </ol>
                    </li>
                  </ol>
                  <p>
                    Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.
                  </p>'
            ]
        ],
        'colors' => [
            'label' => 'Colors',
            'options' => [
                'brandColors' => [
                    [
                        'label' => 'Red',
                        'hex' => '#F44336',
                        'rgba' => 'rgba(244, 67, 54, 1)',
                    ],
                    [
                        'label' => 'Green',
                        'hex' => '#4CAF50',
                        'rgba' => 'rgba(76, 175, 81, 1)',
                    ],
                    [
                        'label' => 'Blue',
                        'hex' => '#2196F3',
                        'rgba' => 'rgba(33, 150, 243, 1)',
                    ],
                ],
                'grayscale' => [
                    [
                        'label' => 'Black',
                        'hex' => '#000',
                        'rgba' => 'rgba(0, 0, 0, 1)',
                    ],
                    [
                        'label' => 'Black 95',
                        'hex' => '#0d0d0d',
                        'rgba' => 'rgba(13, 13, 13, 1)',
                    ],
                    [
                        'label' => 'Black 90',
                        'hex' => '#1a1a1a',
                        'rgba' => 'rgba(26, 26, 26, 1)',
                    ],
                    [
                        'label' => 'Black 85',
                        'hex' => '#262626',
                        'rgba' => 'rgba(38, 38, 38, 1)',
                    ],
                    [
                        'label' => 'Black 80',
                        'hex' => '#333333',
                        'rgba' => 'rgba(51, 51, 51, 1)',
                    ],
                    [
                        'label' => 'Black 75',
                        'hex' => '#404040',
                        'rgba' => 'rgba(64, 64, 64, 1)',
                    ],
                    [
                        'label' => 'Black 70',
                        'hex' => '#4d4d4d',
                        'rgba' => 'rgba(77, 77, 77, 1)',
                    ],
                    [
                        'label' => 'Black 65',
                        'hex' => '#595959',
                        'rgba' => 'rgba(89, 89, 89, 1)',
                    ],
                    [
                        'label' => 'Black 60',
                        'hex' => '#666666',
                        'rgba' => 'rgba(102, 102, 102, 1)',
                    ],
                    [
                        'label' => 'Black 55',
                        'hex' => '#737373',
                        'rgba' => 'rgba(115, 115, 115, 1)',
                    ],
                    [
                        'label' => 'Black 50',
                        'hex' => '#808080',
                        'rgba' => 'rgba(128, 128, 128, 1)',
                    ],
                    [
                        'label' => 'Black 45',
                        'hex' => '#8c8c8c',
                        'rgba' => 'rgba(140, 140, 140, 1)',
                    ],
                    [
                        'label' => 'Black 40',
                        'hex' => '#999999',
                        'rgba' => 'rgba(153, 153, 153, 1)',
                    ],
                    [
                        'label' => 'Black 35',
                        'hex' => '#a6a6a6',
                        'rgba' => 'rgba(166, 166, 166, 1)',
                    ],
                    [
                        'label' => 'Black 30',
                        'hex' => '#b3b3b3',
                        'rgba' => 'rgba(179, 179, 179, 1)',
                    ],
                    [
                        'label' => 'Black 25',
                        'hex' => '#bfbfbf',
                        'rgba' => 'rgba(191, 191, 191, 1)',
                    ],
                    [
                        'label' => 'Black 20',
                        'hex' => '#cccccc',
                        'rgba' => 'rgba(204, 204, 204, 1)',
                    ],
                    [
                        'label' => 'Black 15',
                        'hex' => '#d9d9d9',
                        'rgba' => 'rgba(217, 217, 217, 1)',
                    ],
                    [
                        'label' => 'Black 10',
                        'hex' => '#e6e6e6',
                        'rgba' => 'rgba(230, 230, 230, 1)',
                    ],
                    [
                        'label' => 'Black 05',
                        'hex' => '#f2f2f2',
                        'rgba' => 'rgba(242, 242, 242, 1)',
                    ],
                    [
                        'label' => 'White',
                        'hex' => '#fff',
                        'rgba' => 'rgba(255, 255, 255, 1)',
                    ],
                ],
            ],
        ],
    ],
];

==> generator-baukasten-4.1.5.tgz: package/generators/app/templates/___src/_craftCMS3/craft-gonzo.php <==
<?php
return [
    "compFolders" => [
        "_atoms",
        "_molecules",
        "_organisms",
        "_embeds",
        "_views"
    ],
    "mqButtons" => [
        "min" => "320px",
        "xs" => "400px",
        "s" => "600px",
        "m" => "800px",
        "l" => "1000px",
        "max" => "1440px",
        "fluid" => "100vw"
    ],
    "compStatus" => [
        0 => ["name" => "wip", "color" => "#FF9800"],
        1 => ["name" => "review", "color" => "#369BF4"],
        2 => ["name" => "done", "color" => "#4CAF50"],
        3 => ["name" => "discarded", "color" => "#F44336"],
    ],
    "pages" => [
        'typography' => [
            'label' => 'Typography',
            'options' => [
                'glyphsLower' => [
                    'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
                    'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
                ],
                'glyphsUpper' => [
                    'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
                    'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
                ],
                'glyphsLigatures' => [
                    'ﬀ', 'ﬁ', 'ﬂ', 'ﬃ', 'ﬄ'
                ],
                'glyphsPunctuation' => [
                    '!', '"', '#', '%', '&', '\'', '(', ')', '*', ',', '.', '/', ':', ';',
                    '?', '@', '[', '\\', ']', '^', '_', '`', '{', '|', '}', '˜', '¡', '¦',
                    '§', '¨', '©', 'ª', '«', '¬', '®', '¯', '²', '³', '´', '¶', '·', '¹',
                    'º', '»', '¿', '‐', '–', '—', '―', '‘', '’', '‚', '“', '”', '„', '•',
                    '™',
                ],
                'glyphsCurrency' => [
                    '$', '¢', '£', '€', '¥', '฿'
                ],
                'headline' => 'The quick brown fox jumps over a Dog. Zwei Boxkämpfer jagen Eva durch Sylt portez ce vieux Whiskey blond.',
                'textSimple' => '
                  <p>
                    Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.
                  </p>',
                'textFull' => '
                  <p>
                    Shooting <del>highlining</del> in front of the <strong>supermoo*n</strong> was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical <mark>landscape photograph</mark>. It started as a simple challenge to myself and I <a href="#">quickly became</a> immersed in the process of figuring out how to shoot it.
                  </p>
                  <ul>
                    <li>Shooting highlining in front of the supermoo</li>
                    <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                    <li>I’ve *chased to date.
                      <ul>
                        <li>Shooting highlining in front of the supermoo</li>
                        <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                        <li>I’ve *chased to date.</li>
                      </ul>
                    </li>
                  </ul>
                  <p>
                    <em>Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.</em>
                  </p>
                  <p>
                    <strong>Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.</strong>
                  </p>
                  <ol>
                    <li>Shooting highlining in front of the supermoo</li>
                    <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                    <li>I’ve *chased to date.
                      <ol>
                        <li>Shooting highlining in front of the supermoo</li>
                        <li>One of the most difficu*lt shots I’ve *chased to date.</li>
                        <li>I’ve *chased to date.</li>
                      </ol>
                    </li>
                  </ol>
                  <p>
                    Shooting highlining in front of the supermoo*n was one of the most difficu*lt shots I’ve *chased to date. It is a completely hybrid process between shooting an action sport in the midst of a very technical landscape photograph.
                  </p>'
            ]
        ],
        'colors' => [
            'label' => 'Colors',
            'options' => [
                'brandColors' => [
                    [
                        'label' => 'Red',
                        'hex' => '#F44336',
                        'rgba' => 'rgba(244, 67, 54, 1)',
                    ],
                    [
                        'label' => 'Green',
                        'hex' => '#4CAF50',
                        'rgba' => 'rgba(76, 175, 81, 1)',
                    ],
                    [
                        'label' => 'Blue',
                        'hex' => '#2196F3',
                        'rgba' => 'rgba(33, 150, 243, 1)',
                    ],
                ],
                'grayscale' => [
                    [
                        'label' => 'Black',
                        'hex' => '#000',
                        'rgba' => 'rgba(0, 0, 0, 1)',
                    ],
                    [
                        'label' => 'Black 95',
                        'hex' => '#0d0d0d',
                        'rgba' => 'rgba(13, 13, 13, 1)',
                    ],
                    [
                        'label' => 'Black 90',
                        'hex' => '#1a1a1a',
                        'rgba' => 'rgba(26, 26, 26, 1)',
                    ],
                    [
                        'label' => 'Black 85',
                        'hex' => '#262626',
                        'rgba' => 'rgba(38, 38, 38, 1)',
                    ],
                    [
                        'label' => 'Black 80',
                        'hex' => '#333333',
                        'rgba' => 'rgba(51, 51, 51, 1)',
                    ],
                    [
                        'label' => 'Black 75',
                        'hex' => '#404040',
                        'rgba' => 'rgba(64, 64, 64, 1)',
                    ],
                    [
                        'label' => 'Black 70',
                        'hex' => '#4d4d4d',
                        'rgba' => 'rgba(77, 77, 77, 1)',
                    ],
                    [
                        'label' => 'Black 65',
                        'hex' => '#595959',
                        'rgba' => 'rgba(89, 89, 89, 1)',
                    ],
                    [
                        'label' => 'Black 60',
                        'hex' => '#666666',
                        'rgba' => 'rgba(102, 102, 102, 1)',
                    ],
                    [
                        'label' => 'Black 55',
                        'hex' => '#737373',
                        'rgba' => 'rgba(115, 115, 115, 1)',
                    ],
                    [
                        'label' => 'Black 50',
                        'hex' => '#808080',
                        'rgba' => 'rgba(128, 128, 128, 1)',
                    ],
                    [
                        'label' => 'Black 45',
                        'hex' => '#8c8c8c',
                        'rgba' => 'rgba(140, 140, 140, 1)',
                    ],
                    [
                        'label' => 'Black 40',
                        'hex' => '#999999',
                        'rgba' => 'rgba(153, 153, 153, 1)',
                    ],
                    [
                        'label' => 'Black 35',
                        'hex' => '#a6a6a6',
                        'rgba' => 'rgba(166, 166, 166, 1)',
                    ],
                    [
                        'label' => 'Black 30',
                        'hex' => '#b3b3b3',
                        'rgba' => 'rgba(179, 179, 179, 1)',
                    ],
                    [
                        'label' => 'Black 25',
                        'hex' => '#bfbfbf',
                        'rgba' => 'rgba(191, 191, 191, 1)',
                    ],
                    [
                        'label' => 'Black 20',
                        'hex' => '#cccccc',
                        'rgba' => 'rgba(204, 204, 204, 1)',
                    ],
                    [
                        'label' => 'Black 15',
                        'hex' => '#d9d9d9',
                        'rgba' => 'rgba(217, 217, 217, 1)',
                    ],
                    [
                        'label' => 'Black 10',
                        'hex' => '#e6e6e6',
                        'rgba' => 'rgba(230, 230, 230, 1)',
                    ],
                    [
                        'label' => 'Black 05',
                        'hex' => '#f2f2f2',
                        'rgba' => 'rgba(242, 242, 242, 1)',
                    ],
                    [
                        'label' => 'White',
                        'hex' => '#fff',
                        'rgba' => 'rgba(255, 255, 255, 1)',
                    ],
                ],
            ],
        ],
    ],
];
